/*
 *  This file is part of xMule2.
 *  Copyright (C) 2003 Timo Kujala <tiku@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "ColorFrameCtrl.h"

#include <wx/dcclient.h>
#include <wx/dc.h>

#define GetRValue(rgb) (((rgb)>>16)&0xff)
#define GetGValue(rgb) (((rgb)>>8)&0xff)
#define GetBValue(rgb) ((rgb)&0xff)

#define max(a,b) ((a)>(b))?(a):(b)

BEGIN_EVENT_TABLE(CColorFrameCtrl,wxControl)
	EVT_PAINT(CColorFrameCtrl::OnPaint)
	EVT_SIZE(CColorFrameCtrl::OnSize)
END_EVENT_TABLE()

/*
 * Constructs our custom control for statistics graphs.
 */
CColorFrameCtrl::CColorFrameCtrl( wxWindow* parent,int id, int wid,int hei )
  : wxControl(parent,id,wxDefaultPosition,wxSize(wid,hei)),
    m_brushBack(wxColour(0,0,0),wxSOLID),
    m_brushFrame(wxColour(0,255,255),wxSOLID)
{
	m_crBackColor  = RGB(  0,   0,   0) ;  // see also SetBackgroundColor
	m_crFrameColor  = RGB(  0, 255, 255) ;  // see also SetFrameColor

} 

CColorFrameCtrl::~CColorFrameCtrl() {
}

void CColorFrameCtrl::SetFrameColor( DWORD color ) {
	m_crFrameColor = color;
	m_brushFrame.SetColour(wxColour(GetRValue(m_crFrameColor),
					GetGValue(m_crFrameColor),
					GetBValue(m_crFrameColor)));

	// clear out the existing garbage, re-start with a clean plot
	Refresh(FALSE);

}


void CColorFrameCtrl::SetBackgroundColor(DWORD color) {
	m_crBackColor = color ;

	m_brushBack.SetColour(wxColour(GetRValue(m_crBackColor),
				       GetGValue(m_crBackColor),
				       GetBValue(m_crBackColor)));

	// clear out the existing garbage, re-start with a clean plot
	Refresh(FALSE);

}

 
void CColorFrameCtrl::OnPaint(wxPaintEvent& evt) {
	wxPaintDC dc(this);

	wxRect rc;
	rc.x=m_rectClient.left;
	rc.y=m_rectClient.top;
	rc.width=m_rectClient.right-m_rectClient.left;
	rc.height=m_rectClient.bottom-m_rectClient.top;

	dc.SetPen(*wxTRANSPARENT_PEN);
	dc.SetBrush(m_brushBack);
	dc.DrawRectangle(rc);

	wxPen kyna(wxColour(0,0,0),1,wxSOLID);
	dc.SetPen(kyna);
	dc.DrawLine(rc.x+1,rc.y+1,rc.x+rc.width-2,rc.y+1);
	dc.DrawLine(rc.x+rc.width-2,rc.y+1,rc.x+rc.width-2,rc.y+rc.height-2);
	dc.DrawLine(rc.x+rc.width-2,rc.y+rc.height-2,rc.x+1,rc.y+rc.height-2);
	dc.DrawLine(rc.x+1,rc.y+rc.height-2,rc.x+1,rc.y+1);

	dc.SetPen(*wxWHITE_PEN);
	dc.DrawLine(rc.x+rc.width-1,rc.y,rc.x+rc.width-1,rc.y+rc.height-1);
	dc.DrawLine(rc.x+rc.width-1,rc.y+rc.height-1,rc.x,rc.y+rc.height-1);
	dc.SetPen(*wxGREY_PEN);
	dc.DrawLine(rc.x+rc.width,rc.y,rc.x,rc.y);
	dc.DrawLine(rc.x,rc.y,rc.x,rc.y+rc.height);

}


void CColorFrameCtrl::OnSize(wxSizeEvent& evt) {

  // NOTE: OnSize automatically gets called during the setup of the control
	
  wxRect rc=GetClientRect();
  m_rectClient.left=rc.x;
  m_rectClient.top=rc.y;
  m_rectClient.right=rc.x+rc.width;
  m_rectClient.bottom=rc.y+rc.height;

}

