/*
 *  This file is part of xMule2.
 *  Copyright (C) 2003 Alo Sarv <madcat_@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
#ifdef __GNUG__
	#pragma implementation "GUISettingsDlg.cpp"
#endif

// For compilers that support precompilation, includes "wx/wx.h".
#include "wx/wxprec.h"

#ifdef __BORLANDC__
	#pragma hdrstop
#endif

#include "GUISettingsDlg.h"
#include "xMuleDlg.h"

/*********************
 * CGUISettingsDlg class 
 *********************/

BEGIN_EVENT_TABLE(CGUISettingsDlg, wxDialog)
	EVT_BUTTON(GUI_OK, CGUISettingsDlg::OnOk)
	EVT_BUTTON(GUI_CANCEL, CGUISettingsDlg::OnCancel)
	EVT_CHECKBOX(ID_REMEMBER_LAST, CGUISettingsDlg::OnCheckRememberLast)
	EVT_CHECKBOX(ID_SHOWMENU, CGUISettingsDlg::OnCheckShowMenu)
	EVT_CHECKBOX(ID_SHOWTOOL, CGUISettingsDlg::OnCheckShowTool)
	EVT_BUTTON(ID_BTN_ADDLANG, CGUISettingsDlg::AddLang)
END_EVENT_TABLE()

/* Constructor for GUI Settings dialog. */
CGUISettingsDlg::CGUISettingsDlg(
	wxWindow *parent, wxWindowID id, const wxString &title,
	const wxPoint &position, const wxSize &size, long style
) : wxDialog(parent, id, title, position, size, style) {
	Dlg_GUI_Settings(this, true, true);
	Center();

	LoadSettings();
}

/*
 * Handles GUI Settings dialog Ok button event - Saves the settings and
 * closes the dialog.
 */
void CGUISettingsDlg::OnOk(wxCommandEvent &event) {
	SaveSettings();
	EndModal(0);
}

/*
 * Handles GUI Settings dialog Cancel button event - closes the dialog.
 */
void CGUISettingsDlg::OnCancel(wxCommandEvent &event) {
	EndModal(0);
}

/*
 * Loads settings from config object and sets up dialog controls values.
 */
void CGUISettingsDlg::LoadSettings() {
	int	font, iconset, tool_align, startpage, numlang;
	bool	show_splash, prompt_exit, show_toolbar, show_menubar, 
		remember_last;
	wxString tmpname;

	/* Read from config. If no value found, &<field> remains unchanged */
	m_config->SetPath(wxT("/General"));
	m_config->Read(wxT("Font"), &font, 0);
	m_config->Read(wxT("Icon set"), &iconset, 0);
	m_config->Read(wxT("Show splashscreen"), &show_splash, true);
	m_config->Read(wxT("Prompt on exit"), &prompt_exit, true);
	m_config->Read(wxT("Show toolbar"), &show_toolbar, true);
	m_config->Read(wxT("Toolbar alignment"), &tool_align, 0);
	m_config->Read(wxT("Show menubar"), &show_menubar, false);
	m_config->Read(wxT("Start page"), &startpage, 0);
	m_config->Read(wxT("Remember last"), &remember_last, true);

	/* Load language data */
	m_config->SetPath(wxT("/General/Lang"));
	m_config->Read(wxT("NumLang"), &numlang, 1);

	for (int i=0; i<numlang; i++) {
		m_config->Read(
			wxString::Format(wxT("%d"), i),
			&tmpname,
			wxT("Default")
		);
		GetLang()->Append(tmpname);
	}
	m_config->Read(wxT("CurLang"), &tmpname, wxT("Default"));
	GetLang()->SetSelection(GetLang()->FindString(tmpname));
#if 0
	for (int i=0; i<numlang; i++) {
		tmp.Clear();
		m_config->Read(tmp<<i, &langname, wxT("Default"));
		wxPuts(wxT("Prefs: Read: ")+langname);
		GetLang()->Append(langname);
	}

	m_config->Read(wxT("CurLang"), &curlang, 0);
#endif
	/* Set controls values to match config values */
	GetFont()->SetSelection(font);
	GetIconSet()->SetSelection(iconset);
	GetShowSplash()->SetValue(show_splash);
	GetPromptExit()->SetValue(prompt_exit);
	GetShowTool()->SetValue(show_toolbar);
	GetShowMenu()->SetValue(show_menubar);
	GetRememberLast()->SetValue(remember_last);
	GetStartPage()->SetSelection(startpage);

	switch (tool_align) {
		case wxTB_HORIZONTAL:	tool_align = 0; break;
		case wxTB_VERTICAL:	tool_align = 1; break;
		default: break;
	}
	GetToolAlign()->SetSelection(tool_align);

	/* If toolbar showing is disabled, disable tool_align control also. */
	GetShowTool()->GetValue() ? 
		GetToolAlign()->Enable() : GetToolAlign()->Disable();

	if (GetRememberLast()->GetValue()) {
		GetStartPage()->Disable();
	}
}

/*
 * Writes control values to config object.
 */
void CGUISettingsDlg::SaveSettings() {
	int old_tool_align, tool_align;
	bool old_show_tool, show_tool;
	bool old_show_menu, show_menu;
	/**
	 * To determine wether we are reading the values for first time.
	 * Starts up as true, but will change to false as soon as a value
	 * is not found in config.
	 */
	bool notfirstload = true;

	m_config->SetPath(wxT("/General"));

	/**
	 * We do some checking here to find out wether toolbar/menubar settings
	 * were changed - if so, we display a messagebox notifying that user needs
	 * to restart the GUI for changes to take effect.
	 */
	notfirstload = m_config->Read(wxT("Toolbar alignment"), &old_tool_align) && notfirstload;
	notfirstload = m_config->Read(wxT("Show toolbar"), &old_show_tool) && notfirstload;
	notfirstload = m_config->Read(wxT("Show menubar"), &old_show_menu) && notfirstload;
	show_tool = GetShowTool()->GetValue();
	tool_align = GetToolAlign()->GetSelection();
	show_menu = GetShowMenu()->GetValue();

	/**
	 * We convert the checkbox value to wx constant for storing in config object.
	 */
	switch (tool_align) {
		case 0: tool_align = wxTB_HORIZONTAL; break;
		case 1: tool_align = wxTB_VERTICAL; break;
		default: break;
	}

	/**
	 * If show_menu or show_tool or tool_align value doesn't match what was 
	 * previously written in config, display the notification box.
	 */
	if (
		((old_show_menu != show_menu) || 
		(old_show_tool != show_tool) || 
		(old_tool_align != tool_align)) &&
		(notfirstload)
	) {
		::wxMessageBox(
			_("Menubar and Toolbar settings changes\n"
			"require interface restart to take effect."), 
			_("Restart needed"),
			wxOK|wxCENTRE|wxICON_INFORMATION
		);
	}

	/* And finally save to config object. */
	m_config->Write(wxT("Font"), GetFont()->GetSelection());
	m_config->Write(wxT("Icon set"), GetIconSet()->GetSelection());
	m_config->Write(wxT("Show splashscreen"), GetShowSplash()->GetValue());
	m_config->Write(wxT("Prompt on exit"), GetPromptExit()->GetValue());
	m_config->Write(wxT("Show toolbar"), GetShowTool()->GetValue());
	m_config->Write(wxT("Toolbar alignment"), tool_align);
	m_config->Write(wxT("Show menubar"), GetShowMenu()->GetValue());
	m_config->Write(wxT("Start page"), GetStartPage()->GetSelection());
	m_config->Write(wxT("Remember last"), GetRememberLast()->GetValue());

	/* Save language data */
	m_config->SetPath(wxT("/General/Lang"));
	for (int i=0; i<GetLang()->GetCount(); i++) {
		m_config->Write(
			wxString::Format(wxT("%d"), i),
			GetLang()->GetString(i)
		);
	}
	m_config->Write(wxT("NumLang"), GetLang()->GetCount());
	m_config->Write(
		wxT("CurLang"), 
		GetLang()->GetString(GetLang()->GetSelection())
	);
}

/*
 * Handles checking/unchecking Remember Last checkbox - enables/disables
 * startpage selection combobox as neccesery.
 */
void CGUISettingsDlg::OnCheckRememberLast(wxCommandEvent &event) {
	if (GetRememberLast()->GetValue()) {
		GetStartPage()->Disable();
	} else {
		GetStartPage()->Enable();
	}
}

/**
 * Handles show_menu checkbox state change events. If menubar displaying
 * is being disabled, make sure that toolbar is enabled, otherwise user
 * loses all ways to control the application.
 */
void CGUISettingsDlg::OnCheckShowMenu(wxCommandEvent &event) {
	if (!GetShowMenu()->GetValue() && !GetShowTool()->GetValue()) {
		GetShowTool()->SetValue(true);
		GetToolAlign()->Enable();
	}
}

/**
 * Handles show_tool checkbox state change events. If toolbar displaying
 * is being disabled, make sure that menubar is enabled, otherwise user
 * loses all ways to control the application.
 * Also, if toolbar displaying is disabled, also disable toolbar alignment
 * choice.
 */
void CGUISettingsDlg::OnCheckShowTool(wxCommandEvent &event) {
	if (!GetShowTool()->GetValue()) {
		if (!GetShowMenu()->GetValue()) {
			GetShowMenu()->SetValue(true);
		}
		GetToolAlign()->Disable();
	} else {
		GetToolAlign()->Enable();
	}
}

/**
 * Constructs a new dialog to collect new language data.
 */
void CGUISettingsDlg::AddLang(wxCommandEvent &event) {
	CAddLanguageDlg *addlangdlg = new CAddLanguageDlg(
		NULL, -1, _("Add new language")
	);
	if (addlangdlg->ShowModal()) {
		GetLang()->Append(addlangdlg->GetLangName()->GetValue());
		GetLang()->SetSelection(GetLang()->GetCount()-1);
	}
	delete addlangdlg;
}



/********************
 * CAddLanguageDlg class 
 ********************/

BEGIN_EVENT_TABLE(CAddLanguageDlg, wxDialog)
	EVT_BUTTON(ID_BTN_ADD_LANG_OK, CAddLanguageDlg::AddLangOk)
	EVT_BUTTON(ID_BTN_ADD_LANG_CANCEL, CAddLanguageDlg::AddLangCancel)
END_EVENT_TABLE()

/* Constructor */
CAddLanguageDlg::CAddLanguageDlg(
	wxWindow *parent, wxWindowID id, const wxString &title,
	const wxPoint &position, const wxSize &size, long style
) : wxDialog(parent, id, title, position, size, style) {
	
	Dlg_AddLanguage(this, true, true);
	Center();

}

/**
 * Handles OK button click in language adding dialog. We do
 * various checking here to ensure the data passed to us is legal
 * (and exists, for that matter), and if everything works as expected,
 * add the new language to language choice box.
 */
void CAddLanguageDlg::AddLangOk(wxCommandEvent &event) {
	wxString name;
	
	/* Get the name and ID from dialog. */
	name = GetLangName()->GetValue();
	
	/* If either of those are empty, message the user and return to dialog */
	if (name.IsEmpty()) {
		wxMessageBox(
			_("You need to enter the name for your new language!\n"
			  "If you no longer wish to add a language, click 'Cancel'"),
			_("Missing information"),
			wxOK|wxICON_INFORMATION
		);
		return;
	}
	
	/* Check if the file passed to us exists in lang subdir */
	wxString filename;
	filename = wxT("lang/")+name+wxT(".mo");
	if (!wxFileExists(filename)) {
		wxMessageBox(
			wxString::Format(_("The file %s does not exist.\n"), filename.c_str())+
			_("Please make sure you specified correct name, and the\n"
			  "translated and compiled .mo file exists in lang subdir."),
			_("File not found"),
			wxOK|wxICON_ERROR
		);
		return;
	}
	
	/* Everything looks more-less ok, display message and return with 'true' */
	wxMessageBox(
		wxString::Format(_("New language %s added.\n"), name.c_str())+
		_("Please restart the interface to test your new language!"),
		_("Success!"),
		wxOK|wxICON_EXCLAMATION
	);
	
	EndModal(true);
}

/**
 * Handles cancel button event in Language adding dialog.
 * Destroys the above-mentioed dialog, plain and simple.
 */
void CAddLanguageDlg::AddLangCancel(wxCommandEvent &event) {
	EndModal(false);
}
