/*
 *  This file is part of xMule2.
 *  Copyright (C) 2003 Alo Sarv <madcat_@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
#ifdef __GNUG__
	#pragma implementation "ServerListCtrl.cpp"
#endif

// For compilers that support precompilation, includes "wx/wx.h".
#include "wx/wxprec.h"

#ifdef __BORLANDC__
	#pragma hdrstop
#endif

#include "ServerListCtrl.h"

BEGIN_EVENT_TABLE(CServerListCtrl, CMListCtrl)
	EVT_LIST_ITEM_SELECTED(-1, CServerListCtrl::ItemSelected)
END_EVENT_TABLE()

/**
 * Constructor for Server List Control. Constructs the list control and
 * column layout.
 */
CServerListCtrl::CServerListCtrl(
	wxWindow*& parent,int id,const wxPoint& pos,wxSize siz,int flags
)
: CMListCtrl(parent,id,pos,siz,flags) {
	/**
	 * Generate the columns for this list control. To add or remove
	 * columns, modify the col_headers array, but make sure the
	 * forloop counter below matches the amount of items in the
	 * array. Column widths data is read from configuration file,
	 * if not present, -1 is used.
	 */
	wxString col_headers[] = {
		_("Server Name"), _("IP"), _("Description"),
		_("Ping"), _("Users"), _("Max Users"),
		_("Files"), _("Preference"), _("Failed"),
		_("Static"), _("Soft File Limit"), _("Hard File Limit"),
		_("Version")
	};
	int widths[13];
	LoadColumnWidths(wxT("/Lists/ServerList/"), &*widths, 13);
	for (int i=0; i<13; i++) {
		InsertColumn(i, col_headers[i], wxLIST_FORMAT_LEFT, widths[i]);
	}

	/* Create and assign image list for this list. */
	wxImageList *serverimages = new wxImageList(16, 16);
	serverimages->Add(img->provider);
	AssignImageList(serverimages, wxIMAGE_LIST_SMALL);

	/* Add some kind of test item to get adding/removing items working. */
	wxArrayString fields_data;
	fields_data.Add(wxT("SomeServerName"));
	fields_data.Add(wxT("123.123.123.123:4662"));
	fields_data.Add(wxT("Some nice server description"));
	AddItem(fields_data);
	fields_data.Clear();

	fields_data.Add(wxT("VeryStrangeServer"));
	fields_data.Add(wxT("234.234.234.234:4662"));
	fields_data.Add(wxT("Yet Another Long Server Description"));
	fields_data.Add(wxT("100ms"));
	fields_data.Add(wxT("10000"));
	fields_data.Add(wxT("150000"));
	fields_data.Add(wxT("2354234"));
	fields_data.Add(wxT("High"));
	fields_data.Add(wxT("0"));
	fields_data.Add(wxT("Yes"));
	fields_data.Add(wxT("1000"));
	fields_data.Add(wxT("2000"));
	AddItem(fields_data);
	fields_data.Clear();

	fields_data.Add(wxT("Third Server"));
	fields_data.Add(wxT("345.345.345.345:4242"));
	fields_data.Add(wxT("BlahServer(tm)"));
	fields_data.Add(wxT("250ms"));
	fields_data.Add(wxT("5000"));
	fields_data.Add(wxT("9000"));
	fields_data.Add(wxT("100000"));
	fields_data.Add(wxT("Low"));
	fields_data.Add(wxT("2"));
	fields_data.Add(wxT("No"));
	fields_data.Add(wxT("2000"));
	fields_data.Add(wxT("4000"));
	AddItem(fields_data);
	fields_data.Clear();
}

/**
 * Destructor for this list control.
 */
CServerListCtrl::~CServerListCtrl() {
	SaveColumnWidths(wxT("/Lists/ServerList/"));
}

/**
 * Method to add items to this list. First we simply insert a imageitem,
 * and then loop through the array fields_data passed to us and set field
 * datas accordingly.
 */
void CServerListCtrl::AddItem(wxArrayString fields_data) {
	int itemid;
	 
	itemid = InsertItem(GetItemCount(), 0);

	for (size_t i = 0; i < fields_data.GetCount(); i++) {
		SetItem(itemid, i, fields_data.Item(i));
	}
}

/**
 * This method is triggered by EVT_LIST_ITEM_SELECTED event and 
 * will update sidebar data according to currently focused item.
 */
void CServerListCtrl::ItemSelected(wxListEvent &event) {
	int itemid;
	wxListItem item;

	itemid = GetNextItem(-1, wxLIST_NEXT_ALL, wxLIST_STATE_FOCUSED);
	serverwnd->GetSSServerName()->SetLabel(GetItemText(itemid));
}
