/*
 *  This file is part of xMule2.
 *  Copyright (C) 2003 Alo Sarv <madcat_@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __ServerWnd_H__
#define __ServerWnd_H__

#ifdef __GNUG__
	#pragma interface "ServerWnd.cpp"
#endif

#ifndef WX_PRECOMP
	#include "wx/wx.h"
#endif

/* wxWindows headers */
#include <wx/datetime.h>

/* Private headers */
#include "xMuleGUI_wdr.h"
#include "defines.h"
#include "ServerListCtrl.h"
#include "xMuleDlg.h"

/*
 * CServerWnd class.
 */
extern class CServerWnd *serverwnd;
class CServerWnd: public wxPanel
{
friend class CServerListCtrl;

public:
	CServerWnd(
		wxWindow *parent, wxWindowID id = -1, 
		const wxPoint& pos = wxDefaultPosition,
		const wxSize& size = wxDefaultSize,
		long style = wxTAB_TRAVERSAL|wxNO_BORDER|wxNO_FULL_REPAINT_ON_RESIZE
	);
	virtual ~CServerWnd();
	void AddLogLine(wxString text, bool status = false);
	void AddDebugLine(wxString text, bool status = false);
	void AddServerLogLine(wxString text, bool status = false);


private:
	DECLARE_EVENT_TABLE()
	/* Member event handlers */
	void ToggleSidebar(wxCommandEvent &event);
	void ToggleAddServerPanel(wxCommandEvent &event);
	void ToggleUpdateServerPanel(wxCommandEvent &event);
	void ToggleServerSettingsPanel(wxCommandEvent &event);
	void TogglePortSettingsPanel(wxCommandEvent &event);
	void ToggleLogOptionsPanel(wxCommandEvent &event);

	/* Member function declarations */
	void AddNewServer();
	void UpdateFromURL();
	void CreateControls();

	/* Member variable declarations */
	wxImageList *m_imagelist;

	/* Sidebar and its panels */
	wxPanel *sidebar;
	wxPanel *addserverpanel, *updateserverpanel, 
		*settingspanel, *portsettingspanel,
		*logoptionspanel;

	/* Splitter window and its panels */
	wxPanel *top_panel, *bottom_panel;
	wxSplitterWindow *splatter;

	/* Main sizer for this page's controls */
	wxFlexGridSizer *mainsizer;

	/* Getters for dialog controls */
	wxNotebook* GetLogBook()  { return (wxNotebook*) FindWindow( ID_LOGBOOK ); }
	wxTextCtrl* GetLog() { return (wxTextCtrl*) FindWindow( ID_LOG ); }
	wxTextCtrl* GetDebugLog() { return (wxTextCtrl*) FindWindow( ID_DEBUGLOG ); }
	wxTextCtrl* GetServerLog() { return (wxTextCtrl*) FindWindow( ID_SERVERINFO ); }
	wxButton* GetUpdate()  { return (wxButton*) FindWindow( ID_UPDATE ); }
	wxTextCtrl* GetServerlisturl()  { return (wxTextCtrl*) FindWindow( ID_SERVERLISTURL ); }
	wxButton* GetAddtolist()  { return (wxButton*) FindWindow( ID_ADDTOLIST ); }
	wxTextCtrl* GetServerip()  { return (wxTextCtrl*) FindWindow( ID_SERVERIP ); }
	wxStaticText* GetTxtServer()  { return (wxStaticText*) FindWindow( ID_TXT_SERVER ); }
	wxSplitterWindow* GetHorizontalSplitter() { return (wxSplitterWindow*) FindWindow(ID_SERVER_SPLITTER_HORIZONTAL); }
	wxStaticBitmap* GetServerListImage() { return (wxStaticBitmap*) FindWindow(ID_SERVERS_IMAGE); }
	wxStaticBitmap* GetSSBitmapProvider() { return (wxStaticBitmap*) FindWindow(ID_SS_SERVER_IMG); }
	wxButton* GetBtnToggleAddServer() { return (wxButton*) FindWindow(ID_BTN_SHOW_ADDSERVER); }
	wxButton* GetBtnToggleUpdateServer() { return (wxButton*) FindWindow(ID_BTN_SHOW_UPDATELIST); }
	wxButton* GetBtnToggleServerSettings() { return (wxButton*) FindWindow(ID_BTN_SHOW_SERVERSETTINGS); }
	wxButton* GetBtnTogglePortSettings() { return (wxButton*) FindWindow(ID_BTN_SHOW_PORT_OPTIONS); }
	wxButton* GetBtnToggleLogOptions() { return (wxButton*) FindWindow(ID_BTN_SHOW_LOGGINGOPTIONS); }
	wxBitmapButton* GetBtnToggleSidebar() { return (wxBitmapButton*) FindWindow(ID_BTN_TOGGLE_SIDEBAR); }
	wxStaticText* GetSSServerName() { return (wxStaticText*) FindWindow(ID_SS_SERVER_NAME); }
	wxCheckBox* GetSSCheckStatic() { return (wxCheckBox*) FindWindow(ID_CHECK_SS_STATIC); }
};


#endif
