/*
 *  This file is part of xMule2.
 *  Copyright (C) 2003 Alo Sarv <madcat_@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __xMuleDlg_H__
#define __xMuleDlg_H__

#ifdef __GNUG__
    #pragma interface "xMuleDlg.h"
#endif

// Include wxWindows' headers
#ifndef WX_PRECOMP
    #include <wx/wx.h>
#endif

/* Include local headers */
#include "xMuleGUI_wdr.h"
#include "defines.h"
#include "StatusBar.h"
#include "ServerWnd.h"
#include "TransferWnd.h"
#include "SearchWnd.h"
#include "SharedFilesWnd.h"
#include "MessagesWnd.h"
#include "StatisticsWnd.h"
#include "SysTray.h"

/*
 * Constants for xMuleDlg
 */

#define ID_QUIT     100
#define ID_ABOUT    101

/*
 * xMuleDlg class. The main dialog functions like Toolbar and Statusbar
 * stuff go in here.
 */
extern class xMuleDlg *mainframe;
class xMuleDlg: public wxFrame
{
public:
	/* Constructors and destructors */
	xMuleDlg( wxWindow *parent, wxWindowID id, const wxString &title,
		const wxPoint& pos, const wxSize& size, 
		long style, wxLocale &m_locale 
	);
	~xMuleDlg();

	wxLocale &m_locale;

private:
	DECLARE_EVENT_TABLE()
	
	/* Member event handler functions */
	void OnCloseWindow( wxCloseEvent &event );	
	void OnBtnGUIOk(wxCommandEvent &event);
	void OnBtnGUICancel(wxCommandEvent &event);
	
	/* Member functions */	
	void SetActiveDialog(wxWindow* dlg);
	void CreateMyToolBar();
	void CreateSysTray();
	void CreateMenuBar();
	void LoadAndShowDialogPages();

	void ConnectToAnyServer(wxCommandEvent &event);

	void ShowServerWnd(wxCommandEvent &event);
	void ShowTransferWnd(wxCommandEvent &event);
	void ShowSearchWnd(wxCommandEvent &event);
	void ShowSharedFilesWnd(wxCommandEvent &event);
	void ShowMessagesWnd(wxCommandEvent &event);
	void ShowStatisticsWnd(wxCommandEvent &event);
	void ShowGUISettingsDlg(wxCommandEvent &event);

	/* Member variables */
	bool show_tool;			// Wether toolbar should be shown or not.
	bool start_up;			// Should we remember last page between sessions or not
	int m_lastbtn;			// Last toggled toolbar button
	wxSizer *m_mainsizer; 		// Sizer to make dialog pages switching easier.
	wxToolBar *tb;			// Main toolbar
	wxWindow *activewnd;		// Current active dialog page
};


#endif
